@@ -45,9 +45,7 @@
 
 #include "common/dbus/common.h"
 
-K_PLUGIN_FACTORY_WITH_JSON(ActivityLinkingFileItemActionFactory,
-                           "kactivitymanagerd_fileitem_linking_plugin.json",
-                           registerPlugin<FileItemLinkingPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(FileItemLinkingPlugin, "kactivitymanagerd_fileitem_linking_plugin.json")
 
 
 // Private
@@ -87,7 +85,8 @@ void FileItemLinkingPlugin::Private::actionTriggered()
 
     KAMD_DBUS_DECL_INTERFACE(service, Resources/Linking, ResourcesLinking);
 
-    foreach (const auto &item, items.urlList()) {
+    const auto urlList = items.urlList();
+    for (const auto &item : urlList) {
         service.asyncCall(
                 link ? "LinkResourceToActivity" : "UnlinkResourceFromActivity",
                 QString(),
@@ -152,7 +151,7 @@ void FileItemLinkingPlugin::Private::setActions(const ActionList &actions)
         action->deleteLater();
     }
 
-    for (auto actionInfo: actions) {
+    for (const auto& actionInfo: actions) {
         if (actionInfo.icon != "-") {
             auto action = new QAction(nullptr);
 
