@@ -18,21 +18,20 @@
 */
 
 #include "exrcreator.h"
-#include <kio/kio_export.h>
-#include <QImage>
 
+#include <QImage>
 #include <QDebug>
-#include <ksharedconfig.h>
 #include <QFile>
 
 #include <ImfInputFile.h>
 #include <ImfPreviewImage.h>
 
+#include <ksharedconfig.h>
 #include <kconfiggroup.h>
 
 extern "C"
 {
-    KIO_EXPORT ThumbCreator *new_creator()
+    Q_DECL_EXPORT ThumbCreator *new_creator()
     {
         return new EXRCreator;
     }
@@ -40,7 +39,7 @@ extern "C"
 
 bool EXRCreator::create(const QString &path, int, int, QImage &img)
 {
-    Imf::InputFile in ( path.toAscii() );
+    Imf::InputFile in ( QFile::encodeName( path ) );
     const Imf::Header &h = in.header();
 
     if ( h.hasPreviewImage() ) {
@@ -57,7 +56,7 @@ bool EXRCreator::create(const QString &path, int, int, QImage &img)
 	return true;
     } else {
         // do it the hard way
-	// We ignore maximum size when just extracting the thumnail
+	// We ignore maximum size when just extracting the thumbnail
 	// from the header, but it is very expensive to render large
 	// EXR images just to turn it into an icon, so we go back
 	// to honoring it in here.
